use commands::list;
use util::list_files;

mod client;
mod commands;
mod constants;
mod types;
mod util;

pub struct RakutenDriveClient {
    client: client::Client,
}

impl RakutenDriveClient {
    pub async fn try_new(refresh_token_str: String) -> anyhow::Result<Self> {
        let client = client::Client::try_new(refresh_token_str).await?;
        Ok(Self { client })
    }
    pub async fn list(
        &self,
        prefix: &Option<String>,
    ) -> anyhow::Result<types::response::ListFilesResponse> {
        list_files(
            Some(&prefix.clone().unwrap_or("".to_string())),
            &self.client,
        )
        .await
    }
    pub async fn info(
        &self,
        path: &str,
    ) -> anyhow::Result<types::response::FileDetailResponse> {
        let req = types::request::FileDetailRequest {
            host_id: self.client.host_id.clone(),
            path: path.to_string(),
            thumbnail_size: 130,
        };
        self.client.file_detail(req).await
    }
}
